import React from "react";
import { Table } from "react-bootstrap";
import { Order, PizzaOrder } from "../Types";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faTrashCan } from "@fortawesome/free-regular-svg-icons";
import { useAuth } from "../context/auth";

export default function PizzaOrderList({ orders, onDelete }: { orders: Order[], onDelete: (pizzaOrder: PizzaOrder) => void }) {
    const auth = useAuth();

    return <Table className="mt-3" striped bordered hover>
        <thead>
            <tr>
                <th>Jméno</th>
                <th>Objednávka</th>
                <th>Celkem</th>
            </tr>
        </thead>
        <tbody>
            {orders.map(order => <tr key={order.customer}>
                <td>{order.customer}</td>
                <td>{order.pizzaList.map<React.ReactNode>((pizzaOrder, index) =>
                    <span key={index}>
                        {`${pizzaOrder.name}, ${pizzaOrder.size} (${pizzaOrder.price} Kč)`}
                        {auth?.login === order.customer &&
                            <FontAwesomeIcon onClick={() => {
                                onDelete(pizzaOrder);
                            }} title='Odstranit' className='trash-icon' icon={faTrashCan} />
                        }
                    </span>)
                    .reduce((prev, curr) => [prev, <br />, curr])}
                </td>
                <td>{order.totalPrice} Kč</td>
            </tr>)}
        </tbody>
    </Table>
}